@@ -113,17 +113,22 @@ class Index:
         """refreshes the index"""
         return self.http.post(path=F"indexes/{self.index_name}/refresh")
 
-    def search(self, q: str, searchable_attributes: Optional[List[str]] = None,
+    def search(self, q: Union[str, dict], searchable_attributes: Optional[List[str]] = None,
                limit: int = 10, offset: int = 0, search_method: Union[SearchMethods.TENSOR, str] = SearchMethods.TENSOR,
                highlights=None, device: Optional[str] = None, filter_string: str = None,
                show_highlights=True, reranker=None,
-               attributes_to_retrieve: Optional[List[str]] = None
+               attributes_to_retrieve: Optional[List[str]] = None, boost: Optional[Dict[str,List[Union[float, int]]]] = None,
                ) -> Dict[str, Any]:
         """Search the index.
 
         Args:
-            q: string to search, or a pointer/url to an image if the index has
-                treat_urls_and_pointers_as_images set to True
+            q: String to search, or a dictionary of weighted strings to search
+                (with the structure <search string>:<weight float>). Strings
+                to search are text or a pointer/url to an image if the index
+                has treat_urls_and_pointers_as_images set to True. 
+                
+                If queries are weighted, each weight act as a (possibly negative) 
+                multiplier for that query, relative to the other queries. 
             searchable_attributes:  attributes to search
             limit: The max number of documents to be returned
             offset: The number of search results to skip (for pagination)
@@ -161,6 +166,7 @@ class Index:
             "searchMethod": search_method,
             "showHighlights": show_highlights,
             "reRanker": reranker,
+            "boost": boost,
         }
         if attributes_to_retrieve is not None:
             body["attributesToRetrieve"] = attributes_to_retrieve
@@ -227,7 +233,7 @@ class Index:
         client_batch_size: int = None,
         processes: int = None,
         device: str = None,
-        non_tensor_fields: List[str] = []
+        non_tensor_fields: List[str] = None
     ) -> Union[Dict[str, Any], List[Dict[str, Any]]]:
         """Add documents to this index. Does a partial update on existing documents,
         based on their ID. Adds unseen documents to the index.
@@ -251,6 +257,8 @@ class Index:
         Returns:
             Response body outlining indexing result
         """
+        if non_tensor_fields is None:
+            non_tensor_fields = []
         return self._generic_add_update_docs(
             update_method="replace",
             documents=documents, auto_refresh=auto_refresh, server_batch_size=server_batch_size,
@@ -265,7 +273,7 @@ class Index:
         client_batch_size: int = None,
         processes: int = None,
         device: str = None,
-        non_tensor_fields: List[str] = []
+        non_tensor_fields: List[str] = None
     ) -> Union[Dict[str, Any], List[Dict[str, Any]]]:
         """Add documents to this index. Does a partial updates on existing documents,
         based on their ID. Adds unseen documents to the index.
@@ -289,6 +297,8 @@ class Index:
         Returns:
             Response body outlining indexing result
         """
+        if non_tensor_fields is None:
+            non_tensor_fields = []
         return self._generic_add_update_docs(
             update_method="update",
             documents=documents, auto_refresh=auto_refresh, server_batch_size=server_batch_size,
